//
//  AASFilesSubscription.h
//  AASFilesystemTools
//
//  Created by Andreas Schwarz on 11/23/09.
//  Copyright 2009 immaterial. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "AASFilesystemSubscription.h"


@interface AASFilesSubscription : AASFilesystemSubscription {
	NSMutableDictionary *fileItems;
}

/* Designated initializer. Unlike AASDirectorySubscriptions, which you get a shared instance of through the default AASFileManager, you will create for yourself a new AASFilesSubscription object for every group of files you wish to track. You can still handle multiple subscribers through the subscribe: and unsubscribe: methods, but if you do, you are responsible to be sure there are no subscribers still dependent on the AASFilesSubscription object when you release it. */
- (id)initWithFileItems:(NSArray *)files andSubscriber:(id<AASFilesystemSubscriptionProtocol>)sub;

/* Returns an array of the AASFileItem objects being monitored. */
@property(readonly) NSArray * files;

/* Add or remove file items that need to be watched. Note: AASFileItem objects are automatically removed when they are no longer valid (you will receive an AASFileRemovedEvent for it first). */
- (void)removeFileItem:(id)fileItem;
- (void)addFileItem:(id)fileItem;

/* Replaces all files currently being watched with the items in the array. */
- (void)setFileItems:(NSArray *)files;

@end
